### Verification Script ###

####################################################################################################
# Schraff, Dominik. 2020. Asymmetric Ratification Standards and Popular Perceptions of Legitimacy. # 
# Journal of European Public Policy ################################################################

# 1) Study I #

# R version 4.0.3 (2020-10-10) -- "Bunny-Wunnies Freak Out"
# Copyright (C) 2020 The R Foundation for Statistical Computing
# Platform: x86_64-w64-mingw32/x64 (64-bit)

# Set the working directory
setwd("T:/")

library(MASS)
library(ggplot2)
library(stargazer)
library(mediation)
library(effsize)
library(effectsize)

# Load survey data

d <- read.csv("GF20-1989 - Finale Daten.csv")

# Code variables

# Treatment
d$treat <- d$Test
d$treat[d$Control==1] <- 0

# Fairness perception
d$fair.ord <- d$Wie.fair.finden.Sie.den.Ratifizierungsprozess.von.EU.Vereinbarungen..1
d$fair.ord <- as.character(d$fair.ord)
d$fair.ord[d$fair.ord=="sehr unfair"] <- 1
d$fair.ord[d$fair.ord=="etwas unfair"] <- 2
d$fair.ord[d$fair.ord=="weder unfair, noch fair"] <- 3
d$fair.ord[d$fair.ord=="etwas fair"] <- 4
d$fair.ord[d$fair.ord=="sehr fair"] <- 5
d$fair.ord[d$fair.ord==""] <- NA
d$fair.ord <- as.integer(d$fair.ord)

# Satisfaction with EU democracy
d$eu.satdem <- d$Wie.zufrieden.sind.Sie.mit.dem.Funktionieren.der.Demokratie.in.der.EU..1
d$eu.satdem <- as.character(d$eu.satdem)
d$eu.satdem[d$eu.satdem=="überhaupt nicht zufrieden"] <- 1
d$eu.satdem[d$eu.satdem=="nicht so zufrieden"] <- 2
d$eu.satdem[d$eu.satdem=="etwas zufrieden"] <- 3
d$eu.satdem[d$eu.satdem=="sehr zufrieden"] <- 4
d$eu.satdem[d$eu.satdem==""] <- NA
d$eu.satdem <- as.integer(d$eu.satdem)

# Satisfaction with national democracy
d$satdem <- d$Wie.zufrieden.sind.Sie.mit.dem.Funktionieren.der.Demokratie.in.Deutschland..1
d$satdem <- as.character(d$satdem)
d$satdem[d$satdem=="überhaupt nicht zufrieden"] <- 1
d$satdem[d$satdem=="nicht so zufrieden"] <- 2
d$satdem[d$satdem=="etwas zufrieden"] <- 3
d$satdem[d$satdem=="sehr zufrieden"] <- 4
d$satdem[d$satdem==""] <- NA
d$satdem <- as.integer(d$satdem)

# Demographics
d$gender <- d$Sie.sind...
d$gender <- as.character(d$gender)
d$gender[d$gender=="Männlich"] <- "0"
d$gender[d$gender=="Weiblich"] <- "1"
d$gender[d$gender=="Divers"] <- NA
d$gender <- as.integer(d$gender)

d$age <- d$Bitte.teilen.Sie.uns.Ihr.Alter.mit

d$edu <- d$Welches.ist.Ihr.h.chster.erreichter.Bildungsabschluss.
d$edu <- as.character(d$edu)
d$edu[d$edu=="Abitur" | d$edu=="Fachabitur" | d$edu=="Fachhochschulabschluss" |
        d$edu=="Universitätsabschluss"] <- 1
d$edu[d$edu=="Hauptschulabschluss" | d$edu=="Realschulabschluss" | d$edu=="kein Abschluss"] <- 0
d$edu <- as.integer(d$edu)

# Checking balance for randomization

t.test(edu ~ treat, data = d)
t.test(age ~ treat, data = d)
t.test(gender ~ treat, data = d)

#####
# Treatment effects
d$fair.ord <- as.factor(d$fair.ord)
d$eu.satdem <- as.factor(d$eu.satdem)

# Ordered logit

m1 <- polr(fair.ord ~ treat, data = na.omit(d[c("fair.ord","treat","eu.satdem")]))
summary(m1)
exp(coef(m1))

m2 <- polr(eu.satdem ~ treat + fair.ord, data = na.omit(d[c("fair.ord","treat","eu.satdem")]))
summary(m2)
exp(coef(m2))

stargazer(m1, m2, type = "html", out = "exp_regs.html")

# OLS

d$fair.ord <- as.numeric(as.character(d$fair.ord))
d$eu.satdem <- as.numeric(as.character(d$eu.satdem))

m1.ols <- lm(fair.ord ~ treat, data = na.omit(d[c("fair.ord","treat","eu.satdem")]))
summary(m1.ols)

m2.ols <- lm(eu.satdem ~ treat + fair.ord, data = na.omit(d[c("fair.ord","treat","eu.satdem")]))
summary(m2.ols)

stargazer(m1.ols, m2.ols, type = "html", out = "exp_ols.html")

sd(d$fair.ord, na.rm = T)
cohen.d(fair.ord ~ as.factor(treat), data = d, hedges.correction = F, na.rm = T) 

#####
# Mediation analysis

set.seed(1234)

med.fit <- lm(fair.ord ~ treat, 
              data = d)
out.fit <- lm(eu.satdem ~ treat + fair.ord, 
              data = d)

out.pooled <- mediate(med.fit, out.fit, treat = "treat", 
                    mediator = "fair.ord", robustSE = T, sims = 1000, dropobs = T)
summary(out.pooled)
plot(out.pooled)

# With controls

med.fit2 <- lm(fair.ord ~ treat + age + gender + edu, 
              data = d)
out.fit2 <- lm(eu.satdem ~ treat + fair.ord + age + gender + edu, 
              data = d)

out.pooled2 <- mediate(med.fit2, out.fit2, treat = "treat", 
                      mediator = "fair.ord", robustSE = T, sims = 1000, dropobs = T)
summary(out.pooled2)
plot(out.pooled2)

######
# Robustness Checks

# Sensitivity analysis

sens.out <- medsens(out.pooled)
summary(sens.out)
plot(sens.out)

# Effect on national SWD

d$satdem <- as.factor(d$satdem)

m1n <- polr(satdem ~ treat, data = d)
summary(m1n)
exp(coef(m1n))

stargazer(m1n, type = "html", out = "nat_swd.html")



