### Verification Script ###

####################################################################################################
# Schraff, Dominik. 2020. Asymmetric Ratification Standards and Popular Perceptions of Legitimacy. # 
# Journal of European Public Policy ################################################################

# 2) Study II #

# R version 4.0.3 (2020-10-10) -- "Bunny-Wunnies Freak Out"
# Copyright (C) 2020 The R Foundation for Statistical Computing
# Platform: x86_64-w64-mingw32/x64 (64-bit)

# Set the working directory
setwd("T:/")

# Load packages
library(rdd)
library(rddtools)
library(rdrobust)
library(rdlocrand)
library(polycor)
library(psych)
library(ggplot2)
library(lme4)
library(stargazer)
library(htmlTable)
library(gridExtra)
library(tidyverse)
library(MASS)

###
# Load the data

load(file = "eb634_data.RData")

#############
#Descriptives


p1 <- ggplot(subset(eb, eb$type=="NoRef_NoRati"), aes(x=time, y=eu.satdem, group = treat)) +
  geom_smooth(aes(color = treat, linetype  = treat), se = T) +
  geom_vline(xintercept = 0) +
  ylab("satisfaction EU democracy") + ggtitle("No Referendum - Not Ratified")

p2 <- ggplot(subset(eb, eb$type=="NoRef_Rati"), aes(x=time, y=eu.satdem, group = treat)) +
  geom_smooth(aes(color = treat, linetype  = treat), se = T) +
  geom_vline(xintercept = 0) +
  ylab("satisfaction EU democracy") + ggtitle("No Referendum - Ratified")

p3 <- ggplot(subset(eb, eb$type=="Ref_NoRati"), aes(x=time, y=eu.satdem, group = treat)) +
  geom_smooth(aes(color = treat, linetype  = treat), se = T) +
  geom_vline(xintercept = 0) +
  ylab("satisfaction EU democracy") + ggtitle("Referendum - Not Ratified")

p4 <- ggplot(subset(eb, eb$type=="Ref_Rati"), aes(x=time, y=eu.satdem, group = treat)) +
  geom_smooth(aes(color = treat, linetype  = treat), se = T) +
  geom_vline(xintercept = 0) +
  ylab("satisfaction EU democracy") + ggtitle("Referendum - Ratified")

tiff("rdd_grid.tif", units="in", width=8, height=7, res=600)
gridExtra::grid.arrange(p1,p2,p3,p4)
dev.off()

#########
#Analysis

# Balance - pre/post treatment
# No significant differences on background conditions

t1 <- t.test(eb$lr[eb$time==-1], eb$lr[eb$time==1])
t1$p.value

t2 <- t.test(eb$age[eb$time==-1], eb$age[eb$time==1])
t2$p.value

t3 <- t.test(as.numeric(as.character(eb$gender[eb$time==-1])), 
             as.numeric(as.character(eb$gender[eb$time==1])))
t3$p.value

t4 <- t.test(eb$eduy[eb$time==-1], eb$eduy[eb$time==1])
t4$p.value

htmlTable(matrix(round(c(t1$p.value, t2$p.value, t3$p.value, t4$p.value), 
                         digits  = 2),
                 ncol=1,
                 dimnames = list(c("Left-Right", "Age", "Gender", "Education"),
                                 c("p-value"))))

# McCrary sorting test

DCdensity(eb$time)
title(xlab="time (in days)", ylab="density") 

# Window selection

eb.sub <- na.omit(eb[,c("v7", "time", "eu.satdem", "gender",
                        "age", "eduy", "lr", "type")])
eb.sub$gender <- as.integer(as.character(eb.sub$gender))

sat.diff <- eb.sub$satdem.diff
time <- as.integer(eb.sub$time)
sat.dem <- eb.sub$satdem

covars <- eb.sub[,c("gender", "age", "eduy", "lr")]

length(unique(time))

rdd.window.reduc <- rdwinselect(time, covars, statistic = "hotelling",
                                wstep=1, wmin=1, plot=T ,seed=123, 
                                approx = T, level = .15, cutoff = 0)
###
# RDD estimation
# Regime support in the European Union

ran1 <- rdrandinf(eb.sub$eu.satdem[eb.sub$type=="NoRef_NoRati"], 
                  eb.sub$time[eb.sub$type=="NoRef_NoRati"],
                  wl = -1, wr = 1, seed = 123)

ran2 <- rdrandinf(eb.sub$eu.satdem[eb.sub$type=="NoRef_Rati"], 
                  eb.sub$time[eb.sub$type=="NoRef_Rati"],
                  wl = -1, wr = 1, seed = 123)

ran3 <- rdrandinf(eb.sub$eu.satdem[eb.sub$type=="Ref_NoRati"], 
                  eb.sub$time[eb.sub$type=="Ref_NoRati"],
                  wl = -1, wr = 1, seed = 123)

ran4 <- rdrandinf(eb.sub$eu.satdem[eb.sub$type=="Ref_Rati"], 
                  eb.sub$time[eb.sub$type=="Ref_Rati"],
                  wl = -1, wr = 1, seed = 123)

#Plot Effects
rddif1.df <- data.frame(t(ran1$sumstats[c(2:4),]))
names(rddif1.df) <- c("n","mean","sd")
rddif1.df$cil <- rddif1.df$mean - 1.96*(rddif1.df$sd/sqrt(rddif1.df$n))
rddif1.df$ciu <- rddif1.df$mean + 1.96*(rddif1.df$sd/sqrt(rddif1.df$n))
rddif1.df$status <- c("before", "after")
rddif1.df$status <- factor(rddif1.df$status, levels = c("before", "after"))
rddif1.df$group <- "No Referendum - Not Ratified"

rddif2.df <- data.frame(t(ran2$sumstats[c(2:4),]))
names(rddif2.df) <- c("n","mean","sd")
rddif2.df$cil <- rddif2.df$mean - 1.96*(rddif2.df$sd/sqrt(rddif2.df$n))
rddif2.df$ciu <- rddif2.df$mean + 1.96*(rddif2.df$sd/sqrt(rddif2.df$n))
rddif2.df$status <- c("before", "after")
rddif2.df$status <- factor(rddif2.df$status, levels = c("before", "after"))
rddif2.df$group <- "No Referendum - Ratified"

rddif3.df <- data.frame(t(ran3$sumstats[c(2:4),]))
names(rddif3.df) <- c("n","mean","sd")
rddif3.df$cil <- rddif3.df$mean - 1.96*(rddif3.df$sd/sqrt(rddif3.df$n))
rddif3.df$ciu <- rddif3.df$mean + 1.96*(rddif3.df$sd/sqrt(rddif3.df$n))
rddif3.df$status <- c("before", "after")
rddif3.df$status <- factor(rddif3.df$status, levels = c("before", "after"))
rddif3.df$group <- "Referendum - Not Ratified"

rddif4.df <- data.frame(t(ran4$sumstats[c(2:4),]))
names(rddif4.df) <- c("n","mean","sd")
rddif4.df$cil <- rddif4.df$mean - 1.96*(rddif4.df$sd/sqrt(rddif4.df$n))
rddif4.df$ciu <- rddif4.df$mean + 1.96*(rddif4.df$sd/sqrt(rddif4.df$n))
rddif4.df$status <- c("before", "after")
rddif4.df$status <- factor(rddif4.df$status, levels = c("before", "after"))
rddif4.df$group <- "Referendum - Ratified"

rdddif.type <- rbind(rddif1.df, rddif2.df, rddif3.df, rddif4.df)

ggplot(rdddif.type, aes(x=status, y=mean, shape = group)) + 
  geom_pointrange(aes(ymin=cil, ymax=ciu), position = position_dodge(width = 0.2)) +
  ylab("satisfaction EU democracy") +
  xlab("treatment status") +
  theme_classic() +
  theme(legend.title=element_blank(), text = element_text(size = 14))

# Effect restricted to the following countries
table(eb.sub$v7[eb.sub$type=="NoRef_NoRati"])

# Effect holds for selected window -/+4
ran1.a <- rdrandinf(eb.sub$eu.satdem[eb.sub$type=="NoRef_NoRati"], 
                  eb.sub$time[eb.sub$type=="NoRef_NoRati"],
                  wl = -4, wr = 4, seed = 123)

# Effect robust with continuity-based appraoch

rdd.d <- rdd_data(eb.sub$eu.satdem[eb.sub$type=="NoRef_NoRati"], 
                 eb.sub$time[eb.sub$type=="NoRef_NoRati"], cutpoint = 0)
rdd.lm <- rdd_reg_lm(rdd.d, bw =  rdd_bw_ik(rdd.d))
summary(rdd.lm)

###
# Robustness under multivariate regression

# Linear Regression

library(sjPlot)
library(lfe)
eb.reg <- subset(eb, eb$time==-1 | eb$time==1 | eb$time==0)
table(eb.reg$time)

eb.reg.sub <- subset(eb.reg, eb.reg$type=="NoRef_NoRati")

m0 <- felm(eu.satdem ~ treat + lr + eduy | v7 | 0 |
             v7, data = eb.reg.sub, exactDOF=TRUE, weights = eb.reg.sub$v8)
summary(m0)

stargazer(m0, type = "html", out = "ols_check.html")

# Ordered Logit

m1 <- polr(as.factor(eu.satdem) ~ treat + lr + eduy + v7, weights = eb.reg.sub$v8,
             data = eb.reg.sub)
summary(m1)

# With country-level controls

cpds <- read.csv("cpds_2005.csv")
unique(cpds$country)
table(eb$v7)
cpds$v7[cpds$country=="Austria"] <- "AT"
cpds$v7[cpds$country=="Belgium"] <- "BE"
cpds$v7[cpds$country=="Bulgaria"] <- "BG"
cpds$v7[cpds$country=="Cyprus"] <- "CY"
cpds$v7[cpds$country=="Czech Republic"] <- "CZ"
cpds$v7[cpds$country=="Germany"] <- "DE"
cpds$v7[cpds$country=="Denmark"] <- "DK"
cpds$v7[cpds$country=="Estonia"] <- "EE"
cpds$v7[cpds$country=="Spain"] <- "ES"
cpds$v7[cpds$country=="Finland"] <- "FI"
cpds$v7[cpds$country=="United Kingdom"] <- "GB"
cpds$v7[cpds$country=="Greece"] <- "GR"
cpds$v7[cpds$country=="Hungary"] <- "HU"
cpds$v7[cpds$country=="Ireland"] <- "IE"
cpds$v7[cpds$country=="Italy"] <- "IT"
cpds$v7[cpds$country=="Lithuania"] <- "LT"
cpds$v7[cpds$country=="Luxembourg"] <- "LU"
cpds$v7[cpds$country=="Latvia"] <- "LV"
cpds$v7[cpds$country=="Malta"] <- "MT"
cpds$v7[cpds$country=="Poland"] <- "PL"
cpds$v7[cpds$country=="Portugal"] <- "PT"
cpds$v7[cpds$country=="Romania"] <- "RO"
cpds$v7[cpds$country=="Sweden"] <- "SE"
cpds$v7[cpds$country=="Slovenia"] <- "SI"
cpds$v7[cpds$country=="Slovakia"] <- "SK"

eb.reg <- subset(eb, eb$time==-1 | eb$time==1)

eb.reg <- merge(eb.reg, cpds, by = "v7")
eb.reg$treat[eb.reg$time==0] <- 0

eb.reg$ineq.d[eb.reg$type=="NoRef_NoRati"] <- 1
eb.reg$ineq.d[eb.reg$type!="NoRef_NoRati"] <- 0

# Multi-Level Model

glm1 <- lmer(eu.satdem ~ treat*ineq.d +
               (1 | v7), data = eb.reg)
summary(glm1)

glm1a <- lmer(eu.satdem ~ treat*ineq.d +
                treat*unemp +
               (1 | v7), data = eb.reg)
summary(glm1a)

glm1b <- lmer(eu.satdem ~ treat*ineq.d +
                treat*realgdpgr +
                (1 | v7), data = eb.reg)
summary(glm1b)

glm1c <- lmer(eu.satdem ~ treat*ineq.d +
                treat*natparltrust.avrg +
                (1 | v7), data = eb.reg)
summary(glm1c)

glm1d <- lmer(eu.satdem ~ treat*ineq.d +
                treat*emu +
                (1 | v7), data = eb.reg)
summary(glm1d)

stargazer(glm1, glm1a, glm1b, glm1c, glm1d, type = "html",
          out = "glm_check.html")

# Holds with dummy DV

glm2a <- glmer(eusat.d ~ treat*ineq.d +
                (1 | v7), 
              data = eb.reg, family = "binomial")
summary(glm2a)

###
# Results for national SWD

ran1n <- rdrandinf(eb$satdem[eb$type=="NoRef_NoRati"], 
                   eb$time[eb$type=="NoRef_NoRati"],
                  wl = -1, wr = 1, seed = 123)

ran2n <- rdrandinf(eb$satdem[eb$type=="NoRef_Rati"], 
                   eb$time[eb$type=="NoRef_Rati"],
                  wl = -1, wr = 1, seed = 123)

ran3n <- rdrandinf(eb$satdem[eb$type=="Ref_NoRati"], 
                   eb$time[eb$type=="Ref_NoRati"],
                  wl = -1, wr = 1, seed = 123)

ran4n <- rdrandinf(eb$satdem[eb$type=="Ref_Rati"], 
                   eb$time[eb$type=="Ref_Rati"],
                  wl = -1, wr = 1, seed = 123)
